@@ -12,7 +12,7 @@ except ImportError:
     from backports.shutil_get_terminal_size import get_terminal_size
 
 SIZE = tuple(get_terminal_size((80, 24)))
-CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789|!?.+-_=@#$%&()/:;, "
+CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789|!?.+-_=@#$%&()/:;,' \""
 
 
 class Enum:
@@ -91,23 +91,46 @@ class FONTFACES(Enum):
     simple3d = "simple3d"
     chrome = "chrome"
     huge = "huge"
+    grid = "grid"
+    pallet = "pallet"
+    shade = "shade"
+    slick = "slick"
 
 
 ANSI_COLORS = {
-    "black": [30, 39],
-    "red": [31, 39],
-    "green": [32, 39],
-    "yellow": [33, 39],
-    "blue": [34, 39],
-    "magenta": [35, 39],
-    "cyan": [36, 39],
-    "white": [37, 39],
-    "gray": [90, 39],
-    "bright_red": [91, 39],
-    "bright_green": [92, 39],
-    "bright_yellow": [93, 39],
-    "bright_blue": [94, 39],
-    "bright_magenta": [95, 39],
-    "bright_cyan": [96, 39],
-    "bright_white": [97, 39],
+    "black": 30,
+    "red": 31,
+    "green": 32,
+    "yellow": 33,
+    "blue": 34,
+    "magenta": 35,
+    "cyan": 36,
+    "white": 37,
+    "gray": 90,
+    "bright_red": 91,
+    "bright_green": 92,
+    "bright_yellow": 93,
+    "bright_blue": 94,
+    "bright_magenta": 95,
+    "bright_cyan": 96,
+    "bright_white": 97,
+}
+
+ANSI_RGB = {
+    "black": (0, 0, 0),
+    "red": (127, 0, 0),
+    "green": (0, 127, 0),
+    "yellow": (127, 127, 0),
+    "blue": (0, 0, 127),
+    "magenta": (127, 0, 127),
+    "cyan": (0, 127, 127),
+    "white": (127, 127, 127),
+    "gray": (64, 64, 64),
+    "bright_red": (255, 0, 0),
+    "bright_green": (0, 255, 0),
+    "bright_yellow": (255, 255, 0),
+    "bright_blue": (0, 0, 255),
+    "bright_magenta": (255, 0, 255),
+    "bright_cyan": (0, 255, 255),
+    "bright_white": (255, 255, 255),
 }
